marktools.get_articulation_attached_to_component
================================================

.. autofunction:: abjad.tools.marktools.get_articulation_attached_to_component.get_articulation_attached_to_component
